==> igniteui-react-16.16.2.tgz: package/esm2015/lib/FloatPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
/**
 * @hidden
 */
export let FloatPaneAction = /*@__PURE__*/ (() => {
    class FloatPaneAction extends PaneDragAction {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.g = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.c.d = this.g;
        }
        get b() {
            let ret_ = this.d.c("type");
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(PaneDragActionType_$type, a);
            this.d.i("type", value_);
        }
        get a() {
            let ret_ = this.d.c("location");
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.d.i("location", value_);
        }
        get f() {
            let ret_ = this.d.c("width");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.d.i("width", value_);
        }
        get e() {
            let ret_ = this.d.c("height");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.i("height", value_);
        }
    }
    FloatPaneAction.$t = /*@__PURE__*/ markType(FloatPaneAction, 'FloatPaneAction', PaneDragAction.$);
    return FloatPaneAction;
})();

==> igniteui-react-18.6.0.tgz: package/esm2015/lib/FloatPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { DockManagerPoint } from "./DockManagerPoint";
/**
 * @hidden
 */
export let FloatPaneAction = /*@__PURE__*/ (() => {
    class FloatPaneAction extends PaneDragAction {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.g = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.g;
        }
        set nativeElement(a) {
            this.g = a;
            this.c.o = this.g;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.d.n("type");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.d.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.d.v("type", value_);
        }
        get a() {
            let ret_ = this.d.m("location", (a) => new DockManagerPoint());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.d.v("location", value_);
        }
        get f() {
            let ret_ = this.d.n("width");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.d.v("width", value_);
        }
        get e() {
            let ret_ = this.d.n("height");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.v("height", value_);
        }
    }
    FloatPaneAction.$t = /*@__PURE__*/ markType(FloatPaneAction, 'FloatPaneAction', PaneDragAction.$);
    return FloatPaneAction;
})();
